@@ -12,7 +12,7 @@ namespace dplyr {
         private:
             
             const Rcpp::DataFrame& data ;
-            std::vector<VectorVisitor*> visitors ;
+            pointer_vector<VectorVisitor> visitors ;
             Rcpp::CharacterVector visitor_names ;
             int nvisitors ;
             
@@ -27,7 +27,8 @@ namespace dplyr {
             {
                        
                 for( int i=0; i<nvisitors; i++){
-                    visitors.push_back( visitor( data[i] ) ) ;    
+                    VectorVisitor* v = visitor( data[i] ) ;
+                    visitors.push_back(v) ;    
                 }
             }
             DataFrameVisitors( const Rcpp::DataFrame& data_, const Rcpp::CharacterVector& names ) : 
@@ -55,20 +56,34 @@ namespace dplyr {
                 
             } 
             
-            ~DataFrameVisitors(){
-                delete_all( visitors );
-            }     
-            
-            
             template <typename Container>
-            DataFrame subset( const Container& index, const CharacterVector& classes ) const {
+            DataFrame subset_impl( const Container& index, const CharacterVector& classes, traits::false_type ) const {
                 List out(nvisitors);
                 for( int k=0; k<nvisitors; k++){
-                   out[k] = get(k)->subset(index) ;    
+                    out[k] = get(k)->subset(index) ;
                 }
                 structure( out, Rf_length(out[0]) , classes) ;
-                
-                return (SEXP)out ;
+                return out ;
+            }
+            
+            template <typename Container>
+            DataFrame subset_impl( const Container& index, const CharacterVector& classes, traits::true_type ) const {
+                int n = index.size() ;
+                int n_out = std::count( index.begin(), index.end(), TRUE ) ;
+                IntegerVector idx = no_init(n_out) ;
+                for(int i=0, k=0; i<n; i++){
+                    if( index[i] == TRUE ){
+                        idx[k++] = i ;    
+                    }
+                }
+                return subset_impl( idx, classes, traits::false_type() ) ;
+            }
+            
+            template <typename Container>
+            inline DataFrame subset( const Container& index, const CharacterVector& classes ) const {
+                return subset_impl( index, classes, 
+                    typename traits::same_type<Container, LogicalVector>::type() 
+                ) ;
             }
             
             inline int size() const { return nvisitors ; }
@@ -98,7 +113,8 @@ namespace dplyr {
 
     inline DataFrame subset( DataFrame data, LogicalVector test, CharacterVector classes ){
         DataFrameVisitors visitors( data ) ;
-        return visitors.subset(test, classes ) ;
+        DataFrame res = visitors.subset(test, classes ) ;
+        return res ;
     }
 
 
