@@ -9,7 +9,7 @@ namespace dplyr{
         VisitorEqualPredicate( const Visitor& v_ ) : v(v_){}
         
         inline bool operator()(int i, int j) const {
-            return v.equal(i, j) ;
+            return v.equal_or_both_na(i, j) ;
         }
         
     private:
