@@ -3,12 +3,6 @@
 
 namespace dplyr {
     
-    template <typename T>
-    void delete_all( T& value ){
-        for( typename T::iterator it=value.begin(); it!=value.end(); ++it) delete *it ;
-        value.clear() ;
-    }
-    
     template <typename T>
     void delete_all_second( T& value ){
         for( typename T::iterator it=value.begin(); it!=value.end(); ++it) {
@@ -17,7 +11,6 @@ namespace dplyr {
         value.clear() ;
     }
     
-    
 }
 
 #endif
