@@ -126,19 +126,8 @@ Result* count_distinct_result(SEXP vec){
         case INTSXP:
             if( Rf_inherits(vec, "factor" ))
                 return new Count_Distinct<FactorVisitor>( FactorVisitor(vec) ) ;
-            if( Rf_inherits( vec, "Date" ) )
-                return new Count_Distinct< DateVisitor<INTSXP> >( DateVisitor<INTSXP>(vec) ) ;
-            if( Rf_inherits( vec, "POSIXct" ) )
-                return new Count_Distinct<POSIXctVisitor<INTSXP> >( POSIXctVisitor<INTSXP>(vec) ) ;
-
             return new Count_Distinct< VectorVisitorImpl<INTSXP> >( VectorVisitorImpl<INTSXP>(vec) ) ;
         case REALSXP:
-            if( Rf_inherits( vec, "difftime" ) )
-                return new Count_Distinct< DifftimeVisitor<REALSXP> >( DifftimeVisitor<REALSXP>(vec) ) ;
-            if( Rf_inherits( vec, "Date" ) )
-                return new Count_Distinct< DateVisitor<REALSXP> >( DateVisitor<REALSXP>(vec) ) ;
-            if( Rf_inherits( vec, "POSIXct" ) )
-                return new Count_Distinct<POSIXctVisitor<REALSXP> >( POSIXctVisitor<REALSXP>(vec) ) ;
             return new Count_Distinct< VectorVisitorImpl<REALSXP> >( VectorVisitorImpl<REALSXP>(vec) ) ;
         case LGLSXP:  return new Count_Distinct< VectorVisitorImpl<LGLSXP> >( VectorVisitorImpl<LGLSXP>(vec) ) ;
         case STRSXP:  return new Count_Distinct< VectorVisitorImpl<STRSXP> >( VectorVisitorImpl<STRSXP>(vec) ) ;
@@ -166,7 +155,7 @@ Result* row_number_prototype(SEXP call, const LazySubsets& subsets, int nargs ){
 
     if( nargs == 0 ) return new RowNumber_0() ;
 
-    Armor<SEXP> data( CADR(call) );
+    RObject data( CADR(call) );
     if( TYPEOF(data) == LANGSXP && CAR(data) == Rf_install("desc") ){
         data = CADR(data) ;
 
@@ -212,7 +201,7 @@ Result* ntile_prototype( SEXP call, const LazySubsets& subsets, int nargs ){
         stop("could not convert n to scalar integer") ;
     }
 
-    Armor<SEXP> data( CADR(call) );
+    RObject data( CADR(call) );
     if( TYPEOF(data) == LANGSXP && CAR(data) == Rf_install("desc") ){
         data = CADR(data) ;
 
@@ -244,7 +233,7 @@ Result* ntile_prototype( SEXP call, const LazySubsets& subsets, int nargs ){
 template <typename Increment>
 Result* rank_impl_prototype(SEXP call, const LazySubsets& subsets, int nargs ){
     if( nargs != 1) return 0;
-    Armor<SEXP> data( CADR(call) );
+    RObject data( CADR(call) );
 
     if( TYPEOF(data) == LANGSXP && CAR(data) == Rf_install("desc") ){
         data = CADR(data) ;
@@ -306,7 +295,7 @@ struct LeadLag{
         }
     }
 
-    Armor<SEXP> data ;
+    RObject data ;
     int n ;
 
     bool ok ;
@@ -316,7 +305,7 @@ struct LeadLag{
 Result* lead_prototype(SEXP call, const LazySubsets& subsets, int nargs){
     LeadLag args(call) ;
     if( !args.ok ) return 0 ;
-    Armor<SEXP>& data = args.data ;
+    RObject& data = args.data ;
     int n = args.n ;
 
     if( TYPEOF(data) == SYMSXP && subsets.count(data) ) {
@@ -344,7 +333,7 @@ Result* lag_prototype(SEXP call, const LazySubsets& subsets, int nargs){
     LeadLag args(call) ;
     if( !args.ok ) return 0 ;
 
-    Armor<SEXP>& data = args.data ;
+    RObject& data = args.data ;
     int n = args.n ;
 
     if( TYPEOF(data) == SYMSXP && subsets.count(data) ){
@@ -370,7 +359,7 @@ Result* lag_prototype(SEXP call, const LazySubsets& subsets, int nargs){
 template < template <int> class Templ>
 Result* cumfun_prototype(SEXP call, const LazySubsets& subsets, int nargs){
     if( nargs != 1 ) return 0 ;
-    Armor<SEXP> data( CADR(call) );
+    RObject data( CADR(call) );
     if(TYPEOF(data) == SYMSXP) {
         data = subsets.get_variable(data) ;
     }
@@ -912,7 +901,8 @@ DataFrame subset( DataFrame df, const Index& indices, CharacterVector columns, C
 template <typename Index>
 DataFrame subset( DataFrame df, const Index& indices, CharacterVector classes){
     DataFrameVisitors visitors(df) ;
-    return visitors.subset(indices, classes) ;
+    DataFrame res =  visitors.subset(indices, classes) ;
+    return res ;
 }
 
 template <typename Index>
@@ -1018,25 +1008,6 @@ void push_back( Container& x, typename Container::value_type value, int n ){
         x.push_back( value ) ;
 }
 
-std::string get_unsupported_attributes( SEXP v ){
-    SEXP att = ATTRIB(v) ;
-    std::stringstream s ;
-    int i = 0 ;
-    
-    // only allow R_Names. as in R's do_isvector
-    while( att != R_NilValue ){
-        SEXP tag = TAG(att) ;
-        if( !( tag == R_NamesSymbol || tag == Rf_install("comment") ) ) {
-            if( i > 0 ) s << ", " ;
-            i++ ;
-            s << CHAR(PRINTNAME(tag)) ;
-        }
-        att = CDR(att) ;    
-    }
-    
-    return s.str() ; 
-}
-
 void assert_all_white_list(const DataFrame& data){
     // checking variables are on the white list
     int nc = data.size() ;
@@ -1052,11 +1023,6 @@ void assert_all_white_list(const DataFrame& data){
                     name_i.get_cstring() , get_single_class(v) );
             }
             
-            std::string unsupported_attributes = get_unsupported_attributes(v) ;
-            
-            stop( "column '%s' of type %s has unsupported attributes: %s",
-                    name_i.get_cstring() , get_single_class(v), unsupported_attributes );    
-            
         }
     }
 }
@@ -1327,14 +1293,14 @@ dplyr::BoolResult compatible_data_frame( DataFrame& x, DataFrame& y, bool ignore
 
     if( names_y_not_in_x.size() ){
         ok = false ;
-        ss << "Cols in y but not x: " << collapse(names_y_not_in_x) ;
+        ss << "Cols in y but not x: " << collapse(names_y_not_in_x) << ". ";
     }
 
     if( names_x_not_in_y.size() ){
         ok = false ;
-        ss << "Cols in x but not y: " << collapse(names_x_not_in_y) ;
+        ss << "Cols in x but not y: " << collapse(names_x_not_in_y) << ". ";
     }
-
+    
     if(!ok){
         return no_because( ss.str() ) ;
     }
@@ -1413,13 +1379,17 @@ dplyr::BoolResult equal_data_frame(DataFrame x, DataFrame y, bool ignore_col_ord
 
     // train the map in both x and y
     int nrows_x = x.nrows() ;
-    for( int i=0; i<nrows_x; i++) map[i].push_back(i) ;
-
     int nrows_y = y.nrows() ;
+    
+    if( nrows_x != nrows_y )
+        return no_because( "Different number of rows" ) ;
+        
+    for( int i=0; i<nrows_x; i++) map[i].push_back(i) ;
     for( int i=0; i<nrows_y; i++) map[-i-1].push_back(-i-1) ;
-
+    
     RowTrack track_x( "Rows in x but not y: " ) ;
     RowTrack track_y( "Rows in y but not x: " ) ;
+    RowTrack track_mismatch( "Rows with difference occurences in x and y: " ) ;
 
     bool ok = true ;
     Map::const_iterator it = map.begin() ;
@@ -1444,6 +1414,10 @@ dplyr::BoolResult equal_data_frame(DataFrame x, DataFrame y, bool ignore_col_ord
             track_y.record( chunk[0] ) ;
             ok = false ;
         }
+        if( count_left != count_right ){
+            track_mismatch.record( chunk[0] ) ;
+            ok = false ;    
+        }
 
     }
 
@@ -1451,14 +1425,14 @@ dplyr::BoolResult equal_data_frame(DataFrame x, DataFrame y, bool ignore_col_ord
         std::stringstream ss ;
         if( ! track_x.empty() ) ss << track_x.str() ;
         if( ! track_y.empty() ) ss << track_y.str() ;
+        if( ! track_mismatch.empty() ) ss << track_mismatch.str() ;
+        
         return no_because( ss.str() ) ;
     }
 
     if(ok && ignore_row_order) return yes();
 
     if( !ignore_row_order ){
-        if( nrows_x != nrows_y )
-            return no_because( "Different number of rows" ) ;
         for( int i=0; i<nrows_x; i++){
             if( !visitors.equal( i, -i-1) ){
                     return no_because( "Same row values, but different order" ) ;
@@ -1482,8 +1456,10 @@ dplyr::BoolResult all_equal_data_frame( List args, Environment env ){
 
 // [[Rcpp::export]]
 DataFrame union_data_frame( DataFrame x, DataFrame y){
-    if( !compatible_data_frame(x,y) )
-        stop( "not compatible" );
+    BoolResult compat = compatible_data_frame(x,y) ; 
+    if( !compat ){
+        stop( "not compatible: %s", compat.why_not() );
+    }
 
     typedef VisitorSetIndexSet<DataFrameJoinVisitors> Set ;
     DataFrameJoinVisitors visitors(x, y, x.names(), x.names(), true) ;
@@ -1497,8 +1473,10 @@ DataFrame union_data_frame( DataFrame x, DataFrame y){
 
 // [[Rcpp::export]]
 DataFrame intersect_data_frame( DataFrame x, DataFrame y){
-    if( !compatible_data_frame(x,y) )
-        stop( "not compatible" );
+    BoolResult compat = compatible_data_frame(x,y) ; 
+    if( !compat ){
+        stop( "not compatible: %s", compat.why_not() );
+    }
 
     typedef VisitorSetIndexSet<DataFrameJoinVisitors> Set ;
     DataFrameJoinVisitors visitors(x, y, x.names(), x.names(), true ) ;
@@ -1521,8 +1499,10 @@ DataFrame intersect_data_frame( DataFrame x, DataFrame y){
 
 // [[Rcpp::export]]
 DataFrame setdiff_data_frame( DataFrame x, DataFrame y){
-    if( !compatible_data_frame(x,y) )
-        stop( "not compatible" );
+    BoolResult compat = compatible_data_frame(x,y) ; 
+    if( !compat ){
+        stop( "not compatible: %s", compat.why_not() );
+    }
 
     typedef VisitorSetIndexSet<DataFrameJoinVisitors> Set ;
     DataFrameJoinVisitors visitors(y, x, y.names(), y.names(), true ) ;
@@ -1567,7 +1547,7 @@ IntegerVector match_data_frame( DataFrame x, DataFrame y){
 // [[Rcpp::export]]
 DataFrame grouped_df_impl( DataFrame data, ListOf<Symbol> symbols, bool drop ){
     assert_all_white_list(data);
-    DataFrame copy = shallow_copy(data) ;
+    SHALLOW_COPY(copy,data) ;
     copy.attr("vars") = symbols ;
     copy.attr("drop") = drop ;
     if( !symbols.size() )
@@ -1679,7 +1659,7 @@ DataFrame build_index_adj(DataFrame df, ListOf<Symbol> symbols ){
 
 // [[Rcpp::export]]
 DataFrame grouped_df_adj_impl( DataFrame data, ListOf<Symbol> symbols, bool drop ){
-    DataFrame copy = shallow_copy(data) ;
+    SHALLOW_COPY(copy,data) ;
     copy.attr("vars") = symbols ;
     copy.attr("drop") = drop ;
     return build_index_adj(data, symbols) ;
@@ -1905,8 +1885,7 @@ SEXP mutate_grouped(const DataFrame& df, const LazyDots& dots){
     check_not_groups(dots, gdf);
 
     Proxy proxy(gdf) ;
-    Shelter<SEXP> __ ;
-
+    
     NamedListAccumulator<Data> accumulator ;
     int ncolumns = df.size() ;
     CharacterVector column_names = df.names() ;
@@ -1914,43 +1893,51 @@ SEXP mutate_grouped(const DataFrame& df, const LazyDots& dots){
         accumulator.set( column_names[i], df[i] ) ;
     }
 
+    List variables(nexpr) ;
     for( int i=0; i<nexpr; i++){
         Rcpp::checkUserInterrupt() ;
         const Lazy& lazy = dots[i] ;
 
         Environment env = lazy.env() ;
-        SEXP call = lazy.expr() ;
+        Shield<SEXP> call_( lazy.expr() );
+        SEXP call = call_ ;
         SEXP name = lazy.name() ;
-        SEXP variable = R_NilValue ;
-
+        
         proxy.set_env( env ) ;
 
         if( TYPEOF(call) == SYMSXP ){
             if(proxy.has_variable(call)){
-                variable = proxy.get_variable( PRINTNAME(call) ) ;
+                SEXP variable = variables[i] = proxy.get_variable( PRINTNAME(call) ) ;
+                proxy.input( name, variable ) ;
+                accumulator.set( name, variable) ;
             } else {
                 SEXP v = env.find(CHAR(PRINTNAME(call))) ;
                 if( Rf_isNull(v) ){
                     stop( "unknown variable: %s", CHAR(PRINTNAME(call)) );
                 } else if( Rf_length(v) == 1){
-                    Replicator* rep = constant_replicator<Data>(v, gdf.nrows() );
-                    variable = __( rep->collect() );
-                    delete rep ;
+                    boost::scoped_ptr<Replicator> rep( constant_replicator<Data>(v, gdf.nrows() ) );
+                    SEXP variable = variables[i] = rep->collect() ;
+                    proxy.input( name, variable ) ;
+                    accumulator.set( name, variable) ;
                 } else {
-                    Replicator* rep = replicator<Data>(v, gdf) ;
-                    variable = __( rep->collect() );
-                    delete rep ;
+                    boost::scoped_ptr<Replicator> rep( replicator<Data>(v, gdf) ) ;
+                    SEXP variable = variables[i] = rep->collect() ;
+                    proxy.input( name, variable ) ;
+                    accumulator.set( name, variable) ;
                 }
             }
 
         } else if(TYPEOF(call) == LANGSXP){
             proxy.set_call( call );
-            Gatherer* gather = gatherer<Data, Subsets>( proxy, gdf, name ) ;
-            variable = __( gather->collect() ) ;
-            delete gather ;
+            boost::scoped_ptr<Gatherer> gather( gatherer<Data, Subsets>( proxy, gdf, name ) );
+            SEXP variable = variables[i] = gather->collect() ;
+            proxy.input( name, variable ) ;
+            accumulator.set( name, variable) ;
         } else if(Rf_length(call) == 1) {
             boost::scoped_ptr<Gatherer> gather( constant_gatherer<Data, Subsets>( call, gdf.nrows() ) );
-            variable = __( gather->collect() ) ;
+            SEXP variable = variables[i] = gather->collect() ;
+            proxy.input( name, variable ) ;
+            accumulator.set( name, variable) ;
         } else if( Rf_isNull(call) ){
             accumulator.rm(name) ;
             continue ;
@@ -1958,16 +1945,13 @@ SEXP mutate_grouped(const DataFrame& df, const LazyDots& dots){
             stop( "cannot handle" ) ;
         }
 
-        proxy.input( name, variable ) ;
-        accumulator.set( name, variable) ;
+        
     }
 
     return structure_mutate(accumulator, df, classes_grouped<Data>() );
 }
 
 SEXP mutate_not_grouped(DataFrame df, const LazyDots& dots){
-    Shelter<SEXP> __ ;
-
     int nexpr = dots.size() ;
 
     NamedListAccumulator<DataFrame> accumulator ;
@@ -1982,12 +1966,12 @@ SEXP mutate_not_grouped(DataFrame df, const LazyDots& dots){
         Rcpp::checkUserInterrupt() ;
         const Lazy& lazy = dots[i] ;
 
-        SEXP call = lazy.expr() ;
+        Shield<SEXP> call_( lazy.expr() ) ; SEXP call = call_ ;
         SEXP name = lazy.name() ;
         Environment env = lazy.env() ;
         call_proxy.set_env(env) ;
 
-        SEXP result = R_NilValue ;
+        RObject result(R_NilValue) ;
         if( TYPEOF(call) == SYMSXP ){
             if(call_proxy.has_variable(call)){
                 result = call_proxy.get_variable(PRINTNAME(call)) ;
@@ -1996,13 +1980,10 @@ SEXP mutate_not_grouped(DataFrame df, const LazyDots& dots){
             }
         } else if( TYPEOF(call) == LANGSXP ){
             call_proxy.set_call( call );
-
-            // we need to protect the SEXP, that's what the Shelter does
-            result = __( call_proxy.eval() ) ;
-
+            result = call_proxy.eval() ;
         } else if( Rf_length(call) == 1 ){
             boost::scoped_ptr<Gatherer> gather( constant_gatherer<DataFrame,LazySubsets>( call, df.nrows() ) );
-            result = __( gather->collect() ) ;
+            result = gather->collect() ;
         } else if( Rf_isNull(call)) {
             accumulator.rm(name) ;
             continue ;
@@ -2019,9 +2000,8 @@ SEXP mutate_not_grouped(DataFrame df, const LazyDots& dots){
             // ok
         } else if( Rf_length(result) == 1 ){
             // recycle
-            Gatherer* gather = constant_gatherer<DataFrame,LazySubsets>( result, df.nrows() ) ;
-            result = __( gather->collect() ) ;
-            delete gather ;
+            boost::scoped_ptr<Gatherer> gather( constant_gatherer<DataFrame,LazySubsets>( result, df.nrows() ) );
+            result = gather->collect() ;
         } else {
             stop( "wrong result size (%d), expected %d or 1", Rf_length(result), df.nrows() ) ;
         }
@@ -2118,7 +2098,7 @@ SEXP n_distinct(SEXP x){
 
 // [[Rcpp::export]]
 DataFrame as_regular_df(DataFrame df){
-  DataFrame copy = shallow_copy(df) ;
+  SHALLOW_COPY(copy,df) ;
   SET_ATTRIB(copy, strip_group_attributes(df)) ;
   SET_OBJECT(copy, OBJECT(df)) ;
   copy.attr("class") = CharacterVector::create("data.frame") ;
@@ -2127,7 +2107,7 @@ DataFrame as_regular_df(DataFrame df){
 
 // [[Rcpp::export]]
 DataFrame ungroup_grouped_df( DataFrame df){
-  DataFrame copy = shallow_copy(df) ;
+  SHALLOW_COPY(copy,df) ;
   SET_ATTRIB(copy, strip_group_attributes(df)) ;
   return copy ;
 }
