@@ -18,22 +18,23 @@ SEXP summarise_grouped(const DataFrame& df, const LazyDots& dots){
     }
 
     Subsets subsets(gdf) ;
-    Shelter<SEXP> __ ;
     for( int k=0; k<nexpr; k++, i++ ){
         Rcpp::checkUserInterrupt() ;
         const Lazy& lazy = dots[k] ;
         const Environment& env = lazy.env() ;
         
-        Result* res = get_handler( lazy.expr(), subsets, env ) ;
+        Shield<SEXP> expr_(lazy.expr()) ; SEXP expr = expr_ ;
+        boost::scoped_ptr<Result> res( get_handler( expr, subsets, env ) );
         
         // if we could not find a direct Result
         // we can use a GroupedCallReducer which will callback to R
-        if( !res ) res = new GroupedCallReducer<Data, Subsets>( lazy.expr(), subsets, env) ;
-        
-        SEXP result = __( res->process(gdf) ) ;
+        if( !res ) {
+            res.reset( new GroupedCallReducer<Data, Subsets>( lazy.expr(), subsets, env) );
+        }
+        Shield<SEXP> result( res->process(gdf) ) ;
         accumulator.set( lazy.name(), result );
         subsets.input( Symbol(lazy.name()), SummarisedVariable(result) ) ;
-        delete res;
+        
     }
 
     return summarised_grouped_tbl_cpp<Data>(accumulator, gdf );
@@ -48,21 +49,20 @@ SEXP summarise_not_grouped(DataFrame df, const LazyDots& dots){
     std::vector<SEXP> results ;
     NamedListAccumulator<DataFrame> accumulator ;
 
-    Rcpp::Shelter<SEXP> __ ;
     for( int i=0; i<nexpr; i++){
         Rcpp::checkUserInterrupt() ;
         
         const Lazy& lazy = dots[i] ;
         Environment env = lazy.env() ;
-        Result* res = get_handler( lazy.expr(), subsets, env ) ;
+        Shield<SEXP> expr_(lazy.expr()) ; SEXP expr = expr_ ;
         
-        SEXP result ;
+        boost::scoped_ptr<Result> res( get_handler( expr, subsets, env ) ) ;
+        RObject result ;
         if(res) {
-            result = __(res->process( FullDataFrame(df) )) ;
+            result = res->process( FullDataFrame(df) ) ;
         } else {
-            result = __(CallProxy( lazy.expr(), subsets, env).eval()) ;
+            result = CallProxy( lazy.expr(), subsets, env).eval() ;
         }
-        delete res ;
         if( Rf_length(result) != 1 ){
             stop( "expecting result of length one, got : %d", Rf_length(result) ) ;
         }
