@@ -219,7 +219,7 @@ test_that("row_number does not segfault with example from #781", {
 # data.table --------------------------------------------------------------
 
 test_that("filter succeeds even if column called V1 (#615)", {
-  dt <- data.table(x = 1:10 ,V1 = 0)
+  dt <- data.table::data.table(x = 1:10 ,V1 = 0)
   out <- dt %>% group_by(V1) %>% filter(x > 5)
 
   expect_equal(nrow(out), 5)
